@@ -9,28 +9,24 @@
 
 #include "kbbmainwindow.h"
 
-
-
 #include <QFile>
 #include <QHBoxLayout>
 #include <QPointer>
 #include <QWidget>
 
-
-#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KConfigDialog>
-#include <KGameClock>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KScoreDialog>
 
-#include <KStandardGameAction>
+#include <KGameClock>
+#include <KScoreDialog>
+#include <KGameStandardAction>
+
 #include <QStatusBar>
 #include <QIcon>
 #include <QStandardPaths>
 
-
 #include "kbbgamedoc.h"
 #include "kbbgraphicsitemtutorialmarker.h"
 #include "kbblevelconfigurationwidget.h"
@@ -63,33 +59,33 @@ KBBMainWindow::KBBMainWindow()
 
 
 	// Difficulty
-	Kg::difficulty()->addStandardLevelRange(
-		KgDifficultyLevel::VeryEasy, KgDifficultyLevel::ExtremelyHard,
-		KgDifficultyLevel::Medium //default
+	KGameDifficulty::global()->addStandardLevelRange(
+		KGameDifficultyLevel::VeryEasy, KGameDifficultyLevel::ExtremelyHard,
+		KGameDifficultyLevel::Medium //default
 	);
-	Kg::difficulty()->addLevel(new KgDifficultyLevel(
+	KGameDifficulty::global()->addLevel(new KGameDifficultyLevel(
 		1000, QByteArray("config"), i18nc("Difficulty level title", "Configurable")
 	));
-	KgDifficultyGUI::init(this);
-	connect(Kg::difficulty(), &KgDifficulty::currentLevelChanged, this, &KBBMainWindow::levelChanged);
+	KGameDifficultyGUI::init(this);
+	connect(KGameDifficulty::global(), &KGameDifficulty::currentLevelChanged, this, &KBBMainWindow::levelChanged);
 
 
 	// Menu "Game"
-	KStandardGameAction::gameNew(this, &KBBMainWindow::newGame, actionCollection());
-	m_pauseAction = KStandardGameAction::pause(this, &KBBMainWindow::pause, actionCollection());
+	KGameStandardAction::gameNew(this, &KBBMainWindow::newGame, actionCollection());
+	m_pauseAction = KGameStandardAction::pause(this, &KBBMainWindow::pause, actionCollection());
 	QAction* tutorial = actionCollection()->addAction( QStringLiteral( "game_tutorial" ));
 	tutorial->setText(i18n("Start Tutorial"));
 	tutorial->setIcon(QIcon::fromTheme( QStringLiteral( "footprint" )));
 	tutorial->setToolTip(i18n("Start tutorial"));
 	tutorial->setWhatsThis(i18n("<qt>The <b>tutorial</b> is a fast, user friendly and interactive way to learn the rules of the game. Start it if you do not know them!</qt>"));
 	connect(tutorial, &QAction::triggered, this, &KBBMainWindow::startTutorial);
-	KStandardGameAction::quit(this, &QWidget::close, actionCollection());
+	KGameStandardAction::quit(this, &QWidget::close, actionCollection());
 	QAction* sandbox = actionCollection()->addAction( QStringLiteral( "game_sandbox" ));
 	sandbox->setText(i18n("New Sandbox Game"));
 	sandbox->setToolTip(i18n("Start a new sandbox game"));
 	sandbox->setWhatsThis(i18n("<qt><p>In a <b>sandbox game</b>, the solution is displayed at the beginning of the game. This is useful to understand the game principles.</p><p>However: after a while, it is not really fun and you should try to start a real game!</p></qt>"));
 	connect(sandbox, &QAction::triggered, this, &KBBMainWindow::startSandbox);
-	KStandardGameAction::highscores(this, &KBBMainWindow::showHighscores, actionCollection());
+	KGameStandardAction::highscores(this, &KBBMainWindow::showHighscores, actionCollection());
 
 	// Menu "Move"
 	m_doneAction = actionCollection()->addAction( QStringLiteral( "move_done" ));
@@ -97,7 +93,7 @@ KBBMainWindow::KBBMainWindow()
 	m_doneAction->setWhatsThis(i18n("<qt><ul><li>First, you have to place all the balls on the black box. To guess the correct positions of the balls and see how they interact with laser beams, you should use the lasers that are positioned around the black box.</li><li><b>When you think you are done</b>, you should click here.</li></ul><p>Note that it is only possible to click here if you have placed the correct number of balls.</p></qt>"));
 	m_doneAction->setIcon(QIcon::fromTheme( QStringLiteral( "dialog-ok" )));
 	connect(m_doneAction, &QAction::triggered, this, &KBBMainWindow::done);
-	m_solveAction = KStandardGameAction::solve(this, &KBBMainWindow::solve, actionCollection());
+	m_solveAction = KGameStandardAction::solve(this, &KBBMainWindow::solve, actionCollection());
 	m_solveAction->setToolTip(i18n("Give up the game"));
 	m_solveAction->setWhatsThis(i18n("<qt><p>Choose \"<b>Solve</b>\" if you want to give up the current game. The solution will be displayed.</p><p>If you placed all the balls and do not want to give up, choose \"Done!\".</p></qt>"));
 
@@ -106,7 +102,7 @@ KBBMainWindow::KBBMainWindow()
 	m_toggleCursorAction = actionCollection()->addAction( QStringLiteral( "toggle_cursor" ));
 	m_toggleCursorAction->setText(i18n("Enable highlight under mouse"));
 	m_toggleCursorAction->setCheckable(true);
-	const KConfigGroup group = KSharedConfig::openConfig()->group("default");
+	const KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("default"));
 	m_toggleCursorAction->setChecked(group.readEntry<bool>("highlight_enabled", true));
 	connect(m_toggleCursorAction, &QAction::triggered, this, &KBBMainWindow::toggleCursor);
 
@@ -146,37 +142,37 @@ KBBMainWindow::KBBMainWindow()
 	QAction * action = actionCollection()->addAction( QStringLiteral(  "move_down" ) );
 	action->setText( i18n("Move Down") );
 	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardMoveDown);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Down);
+	KActionCollection::setDefaultShortcut(action, Qt::Key_Down);
 	addAction(action);
 
 	action = actionCollection()->addAction( QStringLiteral(  "move_up" ) );
 	action->setText( i18n("Move Up") );
 	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardMoveUp);
-    actionCollection()->setDefaultShortcut(action,Qt::Key_Up);
+	KActionCollection::setDefaultShortcut(action,Qt::Key_Up);
 	addAction(action);
 
 	action = actionCollection()->addAction( QStringLiteral(  "move_left" ) );
 	action->setText( i18n("Move Left") );
 	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardMoveLeft);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Left);
+	KActionCollection::setDefaultShortcut(action, Qt::Key_Left);
 	addAction(action);
 
 	action = actionCollection()->addAction( QStringLiteral(  "move_right" ) );
 	action->setText( i18n("Move Right") );
 	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardMoveRight);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Right);
+	KActionCollection::setDefaultShortcut(action, Qt::Key_Right);
 	addAction(action);
 
 	action = actionCollection()->addAction( QStringLiteral( "switch_ball" ));
 	action->setText(i18n("Switch Ball or Shoot Laser"));
 	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardEnter);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Return);
+	KActionCollection::setDefaultShortcut(action, Qt::Key_Return);
 	addAction(action);
 
 	action = actionCollection()->addAction( QStringLiteral( "switch_marker" ));
 	action->setText(i18n("Switch Marker"));
 	connect(action, &QAction::triggered, m_gameWidget, &KBBScalableGraphicWidget::keyboardSpace);
-    actionCollection()->setDefaultShortcut(action, Qt::Key_Space);
+	KActionCollection::setDefaultShortcut(action, Qt::Key_Space);
 	addAction(action);
 
 
@@ -213,41 +209,41 @@ KBBMainWindow::~KBBMainWindow()
 
 void KBBMainWindow::levelChanged()
 {
-	KgDifficultyLevel::StandardLevel level = Kg::difficultyLevel();
+	KGameDifficultyLevel::StandardLevel level = KGameDifficulty::globalLevel();
 	switch(level) {
-		case KgDifficultyLevel::VeryEasy:
+		case KGameDifficultyLevel::VeryEasy:
 			m_ballNumber = 2;
 			m_columns = 6;
 			m_rows = 6;
 			break;
-		case KgDifficultyLevel::Easy:
+		case KGameDifficultyLevel::Easy:
 		default:
 			m_ballNumber = 4;
 			m_columns = 8;
 			m_rows = 8;
-			level = KgDifficultyLevel::Medium;
+			level = KGameDifficultyLevel::Medium;
 			break;
-		case KgDifficultyLevel::Medium:
+		case KGameDifficultyLevel::Medium:
 			m_ballNumber = 6;
 			m_columns = 10;
 			m_rows = 10;
 			break;
-		case KgDifficultyLevel::Hard:
+		case KGameDifficultyLevel::Hard:
 			m_ballNumber = 8;
 			m_columns = 12;
 			m_rows = 12;
 			break;
-		case KgDifficultyLevel::VeryHard:
+		case KGameDifficultyLevel::VeryHard:
 			m_ballNumber = 11;
 			m_columns = 14;
 			m_rows = 10;
 			break;
-		case KgDifficultyLevel::ExtremelyHard:
+		case KGameDifficultyLevel::ExtremelyHard:
 			m_ballNumber = 15;
 			m_columns = 20;
 			m_rows = 12;
 			break;
-		case KgDifficultyLevel::Custom:
+		case KGameDifficultyLevel::Custom:
 			m_gameWidget->popupText(i18nc("The text may not be too wide. So please use some HTML-BR-tags to have something more or less as wide as in english. Thanks!", "Note: You can change<br />the parameters of<br />custom games in the<br />Settings dialog."));
 			break;
 	}
@@ -260,7 +256,7 @@ void KBBMainWindow::levelChanged()
 void KBBMainWindow::setRunning(bool r)
 {
 	// Difficulty
-	Kg::difficulty()->setGameRunning(r);
+	KGameDifficulty::global()->setGameRunning(r);
 
 	// Clock
 	if (r) {
@@ -343,9 +339,9 @@ void KBBMainWindow::done()
 		} else
 			s = i18nc("The text may not be too wide. So please use some HTML-BR-tags to have something more or less as wide as in english. Thanks!", "Your final score is: %1.<br />I guess you need more practice.", score);
 
-		if ((!m_tutorial->isVisible()) && (!m_sandboxMode) && (Kg::difficultyLevel() != KgDifficultyLevel::Custom) && (score<KBBGameDoc::SCORE_LOST)) {
+		if ((!m_tutorial->isVisible()) && (!m_sandboxMode) && (KGameDifficulty::globalLevel() != KGameDifficultyLevel::Custom) && (score<KBBGameDoc::SCORE_LOST)) {
 			QPointer<KScoreDialog> scoreDialog = new KScoreDialog(KScoreDialog::Score | KScoreDialog::Name, this);
-			scoreDialog->initFromDifficulty(Kg::difficulty());
+			scoreDialog->initFromDifficulty(KGameDifficulty::global());
 
 			KScoreDialog::FieldInfo scoreInfo;
 			scoreInfo[KScoreDialog::Score].setNum(score);
@@ -388,22 +384,14 @@ void KBBMainWindow::settingsChanged()
 	m_customColumns = m_levelConfig->columns();
 	m_customRows = m_levelConfig->rows();
 
-	if (m_level==KgDifficultyLevel::Custom) {
+	if (m_level==KGameDifficultyLevel::Custom) {
 		bool mayRestart = true;
 		if (m_gameDoc->gameReallyStarted())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 			if (KMessageBox::questionTwoActions(this,
-#else
-			if (KMessageBox::questionYesNo(this,
-#endif
 			    i18n("Do you want to cancel the current custom game and start a new one with the new parameters?"), QString(),
 			    KGuiItem(i18nc("@action:button", "Start New Game"), QStringLiteral("view-refresh")),
 			    KStandardGuiItem::cont())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 			    == KMessageBox::SecondaryAction)
-#else
-			    == KMessageBox::No)
-#endif
 				mayRestart = false;
 
 		if (mayRestart)
@@ -428,7 +416,7 @@ void KBBMainWindow::settingsDialog()
 void KBBMainWindow::showHighscores()
 {
 	KScoreDialog scoreDialog(KScoreDialog::Score | KScoreDialog::Name, this);
-	scoreDialog.initFromDifficulty(Kg::difficulty());
+	scoreDialog.initFromDifficulty(KGameDifficulty::global());
 	scoreDialog.exec();
 }
 
@@ -462,7 +450,7 @@ void KBBMainWindow::startTutorial()
 		m_gameDoc->startTutorial();
 		m_solveAction->setEnabled(true);
 		m_pauseAction->setChecked(false);
-		Kg::difficulty()->setEditable(false);
+		KGameDifficulty::global()->setEditable(false);
 
 		// Reset clock but don't start it yet.
 		m_gameClock->restart();
@@ -476,7 +464,7 @@ void KBBMainWindow::toggleCursor()
 {
 	m_gameWidget->toggleCursor();
 
-	KConfigGroup group = KSharedConfig::openConfig()->group("default");
+	KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("default"));
 	group.writeEntry<bool>("highlight_enabled", m_toggleCursorAction->isChecked());
 }
 
@@ -509,7 +497,7 @@ void KBBMainWindow::solving()
 
 void KBBMainWindow::startGame(bool sandboxMode)
 {
-	if (m_level==KgDifficultyLevel::Custom) {
+	if (m_level==KGameDifficultyLevel::Custom) {
 		m_ballNumber = m_customBallNumber;
 		m_columns = m_customColumns;
 		m_rows = m_customRows;
@@ -520,7 +508,7 @@ void KBBMainWindow::startGame(bool sandboxMode)
 
 	m_solveAction->setEnabled(true);
 	m_pauseAction->setChecked(false);
-	Kg::difficulty()->setEditable(true);
+	KGameDifficulty::global()->setEditable(true);
 	m_tutorial->hide();
 	m_gameDoc->newGame(m_ballNumber, m_columns, m_rows);
 	m_gameWidget->newGame(m_columns, m_rows, m_ballNumber);
